# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SettingsWindow(object):
    def setupUi(self, SettingsWindow):
        SettingsWindow.setObjectName("SettingsWindow")
        SettingsWindow.resize(752, 464)
        self.centralwidget = QtWidgets.QWidget(SettingsWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout = QtWidgets.QGridLayout(self.tab)
        self.gridLayout.setObjectName("gridLayout")
        self.label_6 = QtWidgets.QLabel(self.tab)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 0, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.tab)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.label_2 = QtWidgets.QLabel(self.tab)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(self.tab)
        self.label_3.setObjectName("label_3")
        self.verticalLayout.addWidget(self.label_3)
        self.label_4 = QtWidgets.QLabel(self.tab)
        self.label_4.setObjectName("label_4")
        self.verticalLayout.addWidget(self.label_4)
        self.label_5 = QtWidgets.QLabel(self.tab)
        self.label_5.setObjectName("label_5")
        self.verticalLayout.addWidget(self.label_5)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.def_GD = QtWidgets.QLineEdit(self.tab)
        self.def_GD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GD.setObjectName("def_GD")
        self.verticalLayout_2.addWidget(self.def_GD)
        self.def_GDD = QtWidgets.QLineEdit(self.tab)
        self.def_GDD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GDD.setObjectName("def_GDD")
        self.verticalLayout_2.addWidget(self.def_GDD)
        self.def_TOD = QtWidgets.QLineEdit(self.tab)
        self.def_TOD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_TOD.setObjectName("def_TOD")
        self.verticalLayout_2.addWidget(self.def_TOD)
        self.def_FOD = QtWidgets.QLineEdit(self.tab)
        self.def_FOD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_FOD.setObjectName("def_FOD")
        self.verticalLayout_2.addWidget(self.def_FOD)
        self.def_QOD = QtWidgets.QLineEdit(self.tab)
        self.def_QOD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_QOD.setObjectName("def_QOD")
        self.verticalLayout_2.addWidget(self.def_QOD)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.label_9 = QtWidgets.QLabel(self.tab)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_7.addWidget(self.label_9)
        self.label_10 = QtWidgets.QLabel(self.tab)
        self.label_10.setObjectName("label_10")
        self.verticalLayout_7.addWidget(self.label_10)
        self.label_11 = QtWidgets.QLabel(self.tab)
        self.label_11.setObjectName("label_11")
        self.verticalLayout_7.addWidget(self.label_11)
        self.label_12 = QtWidgets.QLabel(self.tab)
        self.label_12.setObjectName("label_12")
        self.verticalLayout_7.addWidget(self.label_12)
        self.label_13 = QtWidgets.QLabel(self.tab)
        self.label_13.setObjectName("label_13")
        self.verticalLayout_7.addWidget(self.label_13)
        self.horizontalLayout.addLayout(self.verticalLayout_7)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.def_GD_std = QtWidgets.QLineEdit(self.tab)
        self.def_GD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GD_std.setObjectName("def_GD_std")
        self.verticalLayout_6.addWidget(self.def_GD_std)
        self.def_GDD_std = QtWidgets.QLineEdit(self.tab)
        self.def_GDD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GDD_std.setObjectName("def_GDD_std")
        self.verticalLayout_6.addWidget(self.def_GDD_std)
        self.def_TOD_std = QtWidgets.QLineEdit(self.tab)
        self.def_TOD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_TOD_std.setObjectName("def_TOD_std")
        self.verticalLayout_6.addWidget(self.def_TOD_std)
        self.def_FOD_std = QtWidgets.QLineEdit(self.tab)
        self.def_FOD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_FOD_std.setObjectName("def_FOD_std")
        self.verticalLayout_6.addWidget(self.def_FOD_std)
        self.def_QOD_std = QtWidgets.QLineEdit(self.tab)
        self.def_QOD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_QOD_std.setObjectName("def_QOD_std")
        self.verticalLayout_6.addWidget(self.def_QOD_std)
        self.horizontalLayout.addLayout(self.verticalLayout_6)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 1, 1, 1)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_8 = QtWidgets.QLabel(self.tab)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_3.addWidget(self.label_8)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.label_7 = QtWidgets.QLabel(self.tab)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_3.addWidget(self.label_7)
        self.verticalLayout_5.addLayout(self.horizontalLayout_3)
        self.gridLayout.addLayout(self.verticalLayout_5, 1, 1, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem1)
        self.label_14 = QtWidgets.QLabel(self.tab_2)
        self.label_14.setObjectName("label_14")
        self.verticalLayout_8.addWidget(self.label_14)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem2)
        self.label_15 = QtWidgets.QLabel(self.tab_2)
        self.label_15.setObjectName("label_15")
        self.verticalLayout_8.addWidget(self.label_15)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem3)
        self.label_16 = QtWidgets.QLabel(self.tab_2)
        self.label_16.setObjectName("label_16")
        self.verticalLayout_8.addWidget(self.label_16)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem4)
        self.horizontalLayout_4.addLayout(self.verticalLayout_8)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem5)
        self.cff_extend = QtWidgets.QLineEdit(self.tab_2)
        self.cff_extend.setMinimumSize(QtCore.QSize(0, 35))
        self.cff_extend.setObjectName("cff_extend")
        self.verticalLayout_4.addWidget(self.cff_extend)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem6)
        self.cff_threshold = QtWidgets.QLineEdit(self.tab_2)
        self.cff_threshold.setMinimumSize(QtCore.QSize(0, 35))
        self.cff_threshold.setObjectName("cff_threshold")
        self.verticalLayout_4.addWidget(self.cff_threshold)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem7)
        self.cff_maxfev = QtWidgets.QLineEdit(self.tab_2)
        self.cff_maxfev.setMinimumSize(QtCore.QSize(0, 35))
        self.cff_maxfev.setObjectName("cff_maxfev")
        self.verticalLayout_4.addWidget(self.cff_maxfev)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem8)
        self.horizontalLayout_4.addLayout(self.verticalLayout_4)
        self.tabWidget.addTab(self.tab_2, "")
        self.verticalLayout_3.addWidget(self.tabWidget)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton_2 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_2.addWidget(self.pushButton_2)
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout_2.addWidget(self.pushButton)
        self.pushButton_3 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_3.setObjectName("pushButton_3")
        self.horizontalLayout_2.addWidget(self.pushButton_3)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        SettingsWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(SettingsWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 752, 26))
        self.menubar.setObjectName("menubar")
        SettingsWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(SettingsWindow)
        self.statusbar.setObjectName("statusbar")
        SettingsWindow.setStatusBar(self.statusbar)

        self.retranslateUi(SettingsWindow)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(SettingsWindow)

    def retranslateUi(self, SettingsWindow):
        _translate = QtCore.QCoreApplication.translate
        SettingsWindow.setWindowTitle(_translate("SettingsWindow", "Settings"))
        self.label_6.setText(_translate("SettingsWindow", "Defaults"))
        self.label.setText(_translate("SettingsWindow", "GD"))
        self.label_2.setText(_translate("SettingsWindow", "GDD"))
        self.label_3.setText(_translate("SettingsWindow", "TOD"))
        self.label_4.setText(_translate("SettingsWindow", "FOD"))
        self.label_5.setText(_translate("SettingsWindow", "QOD"))
        self.label_9.setText(_translate("SettingsWindow", "+/-"))
        self.label_10.setText(_translate("SettingsWindow", "+/-"))
        self.label_11.setText(_translate("SettingsWindow", "+/-"))
        self.label_12.setText(_translate("SettingsWindow", "+/-"))
        self.label_13.setText(_translate("SettingsWindow", "+/-"))
        self.label_8.setText(_translate("SettingsWindow", "Note: Units in fs"))
        self.label_7.setText(_translate("SettingsWindow", "Done"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("SettingsWindow", "Calibration"))
        self.label_14.setText(_translate("SettingsWindow", "Extend ratio"))
        self.label_15.setText(_translate("SettingsWindow", "r<sup>2</sup> threshold"))
        self.label_16.setText(_translate("SettingsWindow", "Max tries"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("SettingsWindow", "CFF Autofit options"))
        self.pushButton_2.setText(_translate("SettingsWindow", "Reset all"))
        self.pushButton.setText(_translate("SettingsWindow", "Close"))
        self.pushButton_3.setText(_translate("SettingsWindow", "Save changes"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    SettingsWindow = QtWidgets.QMainWindow()
    ui = Ui_SettingsWindow()
    ui.setupUi(SettingsWindow)
    SettingsWindow.show()
    sys.exit(app.exec_())
