# -*- coding: utf-8 -*-

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_GeneratorWindow(object):
    def setupUi(self, GeneratorWindow):
        GeneratorWindow.setObjectName("GeneratorWindow")
        GeneratorWindow.resize(984, 877)
        self.centralwidget = QtWidgets.QWidget(GeneratorWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.plotWidget =PlotWidget(self.centralwidget)
        self.plotWidget.setMinimumSize(QtCore.QSize(800, 380))
        self.plotWidget.setObjectName("plotWidget")
        self.verticalLayout_7.addWidget(self.plotWidget)
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setMinimumSize(QtCore.QSize(962, 380))
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.verticalLayout_3.addWidget(self.label)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem1)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_3.addWidget(self.label_2)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem2)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_3.addWidget(self.label_3)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem3)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_3.addWidget(self.label_4)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem4)
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.verticalLayout_3.addWidget(self.label_5)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem5)
        self.label_6 = QtWidgets.QLabel(self.groupBox)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_3.addWidget(self.label_6)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem6)
        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem7)
        self.startLine = QtWidgets.QLineEdit(self.groupBox)
        self.startLine.setMinimumSize(QtCore.QSize(240, 30))
        self.startLine.setText("")
        self.startLine.setObjectName("startLine")
        self.verticalLayout_2.addWidget(self.startLine)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem8)
        self.stopLine = QtWidgets.QLineEdit(self.groupBox)
        self.stopLine.setMinimumSize(QtCore.QSize(0, 30))
        self.stopLine.setObjectName("stopLine")
        self.verticalLayout_2.addWidget(self.stopLine)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem9)
        self.centerLine = QtWidgets.QLineEdit(self.groupBox)
        self.centerLine.setMinimumSize(QtCore.QSize(0, 30))
        self.centerLine.setObjectName("centerLine")
        self.verticalLayout_2.addWidget(self.centerLine)
        spacerItem10 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem10)
        self.pulseLine = QtWidgets.QLineEdit(self.groupBox)
        self.pulseLine.setMinimumSize(QtCore.QSize(0, 30))
        self.pulseLine.setObjectName("pulseLine")
        self.verticalLayout_2.addWidget(self.pulseLine)
        spacerItem11 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem11)
        self.resolutionLine = QtWidgets.QLineEdit(self.groupBox)
        self.resolutionLine.setMinimumSize(QtCore.QSize(0, 30))
        self.resolutionLine.setObjectName("resolutionLine")
        self.verticalLayout_2.addWidget(self.resolutionLine)
        spacerItem12 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem12)
        self.delayLine = QtWidgets.QLineEdit(self.groupBox)
        self.delayLine.setMinimumSize(QtCore.QSize(0, 30))
        self.delayLine.setObjectName("delayLine")
        self.verticalLayout_2.addWidget(self.delayLine)
        spacerItem13 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem13)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.horizontalLayout_4.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        spacerItem14 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem14)
        self.label_7 = QtWidgets.QLabel(self.groupBox)
        self.label_7.setObjectName("label_7")
        self.verticalLayout_5.addWidget(self.label_7)
        spacerItem15 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem15)
        self.label_8 = QtWidgets.QLabel(self.groupBox)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_5.addWidget(self.label_8)
        spacerItem16 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem16)
        self.label_10 = QtWidgets.QLabel(self.groupBox)
        self.label_10.setObjectName("label_10")
        self.verticalLayout_5.addWidget(self.label_10)
        spacerItem17 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem17)
        self.label_9 = QtWidgets.QLabel(self.groupBox)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_5.addWidget(self.label_9)
        spacerItem18 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem18)
        self.label_11 = QtWidgets.QLabel(self.groupBox)
        self.label_11.setObjectName("label_11")
        self.verticalLayout_5.addWidget(self.label_11)
        spacerItem19 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem19)
        self.horizontalLayout_3.addLayout(self.verticalLayout_5)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        spacerItem20 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem20)
        self.GDLine = QtWidgets.QLineEdit(self.groupBox)
        self.GDLine.setMinimumSize(QtCore.QSize(240, 30))
        self.GDLine.setObjectName("GDLine")
        self.verticalLayout_4.addWidget(self.GDLine)
        spacerItem21 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem21)
        self.GDDLine = QtWidgets.QLineEdit(self.groupBox)
        self.GDDLine.setMinimumSize(QtCore.QSize(0, 30))
        self.GDDLine.setObjectName("GDDLine")
        self.verticalLayout_4.addWidget(self.GDDLine)
        spacerItem22 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem22)
        self.TODLine = QtWidgets.QLineEdit(self.groupBox)
        self.TODLine.setMinimumSize(QtCore.QSize(0, 30))
        self.TODLine.setObjectName("TODLine")
        self.verticalLayout_4.addWidget(self.TODLine)
        spacerItem23 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem23)
        self.FODLine = QtWidgets.QLineEdit(self.groupBox)
        self.FODLine.setMinimumSize(QtCore.QSize(0, 30))
        self.FODLine.setObjectName("FODLine")
        self.verticalLayout_4.addWidget(self.FODLine)
        spacerItem24 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem24)
        self.QODLine = QtWidgets.QLineEdit(self.groupBox)
        self.QODLine.setMinimumSize(QtCore.QSize(0, 30))
        self.QODLine.setObjectName("QODLine")
        self.verticalLayout_4.addWidget(self.QODLine)
        spacerItem25 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem25)
        self.horizontalLayout_3.addLayout(self.verticalLayout_4)
        self.horizontalLayout_4.addLayout(self.horizontalLayout_3)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem26 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem26)
        self.label_12 = QtWidgets.QLabel(self.groupBox)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout.addWidget(self.label_12)
        self.delimiterLine = QtWidgets.QLineEdit(self.groupBox)
        self.delimiterLine.setObjectName("delimiterLine")
        self.horizontalLayout.addWidget(self.delimiterLine)
        self.verticalLayout_6.addLayout(self.horizontalLayout)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem27 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem27)
        self.armCheck = QtWidgets.QCheckBox(self.groupBox)
        self.armCheck.setObjectName("armCheck")
        self.horizontalLayout_6.addWidget(self.armCheck)
        spacerItem28 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem28)
        self.verticalLayout_6.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem29 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem29)
        self.label_13 = QtWidgets.QLabel(self.groupBox)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_5.addWidget(self.label_13)
        self.comboBox = QtWidgets.QComboBox(self.groupBox)
        self.comboBox.setMinimumSize(QtCore.QSize(100, 0))
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.horizontalLayout_5.addWidget(self.comboBox)
        spacerItem30 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem30)
        self.verticalLayout_6.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_4.addLayout(self.verticalLayout_6)
        self.verticalLayout_8.addLayout(self.horizontalLayout_4)
        self.verticalLayout_7.addWidget(self.groupBox)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.closeButton = QtWidgets.QPushButton(self.centralwidget)
        self.closeButton.setObjectName("closeButton")
        self.horizontalLayout_7.addWidget(self.closeButton)
        self.pushButton_2 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_7.addWidget(self.pushButton_2)
        self.pushButton_3 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_3.setObjectName("pushButton_3")
        self.horizontalLayout_7.addWidget(self.pushButton_3)
        self.pushButton_4 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_4.setObjectName("pushButton_4")
        self.horizontalLayout_7.addWidget(self.pushButton_4)
        self.verticalLayout_7.addLayout(self.horizontalLayout_7)
        GeneratorWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(GeneratorWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 984, 26))
        self.menubar.setObjectName("menubar")
        GeneratorWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(GeneratorWindow)
        self.statusbar.setObjectName("statusbar")
        GeneratorWindow.setStatusBar(self.statusbar)


        self.retranslateUi(GeneratorWindow)
        QtCore.QMetaObject.connectSlotsByName(GeneratorWindow)

    def retranslateUi(self, GeneratorWindow):
        _translate = QtCore.QCoreApplication.translate
        GeneratorWindow.setWindowTitle(_translate("GeneratorWindow", "Generator"))
        self.groupBox.setTitle(_translate("GeneratorWindow", "Generator"))
        self.label.setText(_translate("GeneratorWindow", "Start"))
        self.label_2.setText(_translate("GeneratorWindow", "Stop "))
        self.label_3.setText(_translate("GeneratorWindow", "Center"))
        self.label_4.setText(_translate("GeneratorWindow", "Pulse Width"))
        self.label_5.setText(_translate("GeneratorWindow", "Resolution"))
        self.label_6.setText(_translate("GeneratorWindow", "Delay"))
        self.startLine.setPlaceholderText(_translate("GeneratorWindow", "PHz or nm"))
        self.stopLine.setPlaceholderText(_translate("GeneratorWindow", "PHz or nm"))
        self.centerLine.setPlaceholderText(_translate("GeneratorWindow", "PHz or nm"))
        self.pulseLine.setPlaceholderText(_translate("GeneratorWindow", "fs"))
        self.resolutionLine.setPlaceholderText(_translate("GeneratorWindow", "nm"))
        self.delayLine.setPlaceholderText(_translate("GeneratorWindow", "fs"))
        self.label_7.setText(_translate("GeneratorWindow", "GD"))
        self.label_8.setText(_translate("GeneratorWindow", "GDD"))
        self.label_10.setText(_translate("GeneratorWindow", "TOD"))
        self.label_9.setText(_translate("GeneratorWindow", "FOD"))
        self.label_11.setText(_translate("GeneratorWindow", "QOD"))
        self.GDLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs"))
        self.GDDLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^2"))
        self.TODLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^3"))
        self.FODLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^4"))
        self.QODLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^5"))
        self.label_12.setText(_translate("GeneratorWindow", "Delimiter"))
        self.delimiterLine.setPlaceholderText(_translate("GeneratorWindow", ","))
        self.armCheck.setText(_translate("GeneratorWindow", "Include Arms"))
        self.label_13.setText(_translate("GeneratorWindow", "Output in "))
        self.comboBox.setItemText(0, _translate("GeneratorWindow", "frequency"))
        self.comboBox.setItemText(1, _translate("GeneratorWindow", "wavelength"))
        self.closeButton.setText(_translate("GeneratorWindow", "Close"))
        self.pushButton_2.setText(_translate("GeneratorWindow", "Save as"))
        self.pushButton_3.setText(_translate("GeneratorWindow", "_currently_unused_"))
        self.pushButton_4.setText(_translate("GeneratorWindow", "Generate and preview"))

from pysprint.ui.plotwidget import PlotWidget

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    GeneratorWindow = QtWidgets.QMainWindow()
    ui = Ui_GeneratorWindow()
    ui.setupUi(GeneratorWindow)
    GeneratorWindow.show()
    sys.exit(app.exec_())

